summaryrefslogtreecommitdiffstats
path: root/kmix/viewapplet.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmix/viewapplet.cpp')
-rw-r--r--kmix/viewapplet.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kmix/viewapplet.cpp b/kmix/viewapplet.cpp
index 6b25dde0..0615c85e 100644
--- a/kmix/viewapplet.cpp
+++ b/kmix/viewapplet.cpp
@@ -22,7 +22,7 @@
// TQt
#include <tqwidget.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqsize.h>
// KDE
@@ -56,11 +56,11 @@ ViewApplet::ViewApplet(TQWidget* parent, const char* name, Mixer* mixer, ViewBas
if ( _viewOrientation == Qt::Horizontal ) {
_layoutMDW = new TQHBoxLayout( this );
- tqsetSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Preferred);
+ setSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Preferred);
}
else {
_layoutMDW = new TQVBoxLayout( this );
- tqsetSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Fixed);
+ setSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Fixed);
}
@@ -139,10 +139,10 @@ void ViewApplet::constructionFinished() {
}
-TQSize ViewApplet::tqsizeHint() const {
- // Basically out main tqlayout knows very good what the sizes should be
- TQSize qsz = _layoutMDW->tqsizeHint();
- //kdDebug(67100) << "ViewApplet::tqsizeHint(): NewSize is " << qsz << "\n";
+TQSize ViewApplet::sizeHint() const {
+ // Basically out main layout knows very good what the sizes should be
+ TQSize qsz = _layoutMDW->sizeHint();
+ //kdDebug(67100) << "ViewApplet::sizeHint(): NewSize is " << qsz << "\n";
return qsz;
}
@@ -196,7 +196,7 @@ void ViewApplet::resizeEvent(TQResizeEvent *qre)
// kdDebug(67100) << "ViewApplet::resizeEvent(). SHOULD resize _layoutMDW to " << qre->size() << endl;
//TQWidget::resizeEvent(qre);
// resizing changes our own tqsizeHint(), because we must take the new PanelSize in account.
// So updateGeometry() is amust for us.
updateGeometry();
}
@@ -196,7 +196,7 @@ void ViewApplet::resizeEvent(TQResizeEvent *qre)
// kdDebug(67100) << "ViewApplet::resizeEvent(). SHOULD resize _layoutMDW to " << qre->size() << endl;
//TQWidget::resizeEvent(qre);
- // resizing changes our own tqsizeHint(), because we must take the new PanelSize in account.
+ // resizing changes our own sizeHint(), because we must take the new PanelSize in account.
// So updateGeometry() is amust for us.
updateGeometry();